@@ -1,5 +1,5 @@
 /* ************************************************************************
- * Copyright (C) 2016-2023 Advanced Micro Devices, Inc. All rights reserved.
+ * Copyright (C) 2016-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -22,22 +22,10 @@
 
 #ifndef ROCBLAS_AUXILIARY_H
 #define ROCBLAS_AUXILIARY_H
-#include "rocblas-export.h"
-#include "rocblas-types.h"
 
-#ifndef ROCBLAS_NO_DEPRECATED_WARNINGS
-#ifndef ROCBLAS_DEPRECATED_MSG
-#ifndef _MSC_VER
-#define ROCBLAS_DEPRECATED_MSG(MSG) __attribute__((deprecated(#MSG)))
-#else
-#define ROCBLAS_DEPRECATED_MSG(MSG) __declspec(deprecated(#MSG))
-#endif
-#endif
-#else
-#ifndef ROCBLAS_DEPRECATED_MSG
-#define ROCBLAS_DEPRECATED_MSG(MSG)
-#endif
-#endif
+#include "rocblas-export.h"
+#include "rocblas-macros.h"
+#include "rocblas-types.h"
 
 /*!\file
  * \brief rocblas-auxiliary.h provides auxilary functions in rocblas
@@ -73,6 +61,11 @@ ROCBLAS_EXPORT rocblas_status rocblas_get_pointer_mode(rocblas_handle        han
                                                        rocblas_pointer_mode* pointer_mode);
 
 /*! \brief Set rocblas_atomics_mode
+ *  \details
+ *  Some rocBLAS functions may have implementations which use atomic operations to increase performance.
+ *  By using atomic operations, results are not guaranteed to be identical between multiple runs.
+ *  Results will be accurate with or without atomic operations. Atomic operations in rocBLAS are turned
+ *  off by default. They can be turned on or off for a handle by calling rocblas_set_atomics_mode.
  */
 ROCBLAS_EXPORT rocblas_status rocblas_set_atomics_mode(rocblas_handle       handle,
                                                        rocblas_atomics_mode atomics_mode);
@@ -82,21 +75,15 @@ ROCBLAS_EXPORT rocblas_status rocblas_set_atomics_mode(rocblas_handle       hand
 ROCBLAS_EXPORT rocblas_status rocblas_get_atomics_mode(rocblas_handle        handle,
                                                        rocblas_atomics_mode* atomics_mode);
 
-ROCBLAS_DEPRECATED_MSG("rocblas_query_int8_layout_flag will be removed in a future release.")
-/*! \brief Query the preferable supported int8 input layout for gemm
-     \details
-    Indicates the supported int8 input layout for gemm according to the device.
-    If the device supports packed-int8x4 (1) only, output flag is rocblas_gemm_flags_pack_int8x4
-    and users must bitwise-or your flag with rocblas_gemm_flags_pack_int8x4.
-    If output flag is rocblas_gemm_flags_none (0), then unpacked int8 is preferable and suggested.
-    @param[in]
-    handle      [rocblas_handle]
-                the handle of device
-    @param[out]
-    flag        pointer to rocblas_gemm_flags
-     ********************************************************************/
-ROCBLAS_EXPORT rocblas_status rocblas_query_int8_layout_flag(rocblas_handle      handle,
-                                                             rocblas_gemm_flags* flag);
+/*! \brief Set rocblas_math_mode
+ */
+ROCBLAS_EXPORT rocblas_status rocblas_set_math_mode(rocblas_handle    handle,
+                                                    rocblas_math_mode math_mode);
+
+/*! \brief Get rocblas_math_mode
+ */
+ROCBLAS_EXPORT rocblas_status rocblas_get_math_mode(rocblas_handle     handle,
+                                                    rocblas_math_mode* math_mode);
 
 /*! \brief  Indicates whether the pointer is on the host or device.
  */
@@ -127,6 +114,9 @@ ROCBLAS_EXPORT rocblas_status rocblas_set_vector(rocblas_int n,
                                                  void*       y,
                                                  rocblas_int incy);
 
+ROCBLAS_EXPORT rocblas_status rocblas_set_vector_64(
+    int64_t n, int64_t elem_size, const void* x, int64_t incx, void* y, int64_t incy);
+
 /*! \brief Copy vector from device to host
     @param[in]
     n           [rocblas_int]
@@ -152,6 +142,9 @@ ROCBLAS_EXPORT rocblas_status rocblas_get_vector(rocblas_int n,
                                                  void*       y,
                                                  rocblas_int incy);
 
+ROCBLAS_EXPORT rocblas_status rocblas_get_vector_64(
+    int64_t n, int64_t elem_size, const void* x, int64_t incx, void* y, int64_t incy);
+
 /*! \brief Copy matrix from host to device
     @param[in]
     rows        [rocblas_int]
@@ -181,6 +174,14 @@ ROCBLAS_EXPORT rocblas_status rocblas_set_matrix(rocblas_int rows,
                                                  void*       b,
                                                  rocblas_int ldb);
 
+ROCBLAS_EXPORT rocblas_status rocblas_set_matrix_64(int64_t     rows,
+                                                    int64_t     cols,
+                                                    int64_t     elem_size,
+                                                    const void* a,
+                                                    int64_t     lda,
+                                                    void*       b,
+                                                    int64_t     ldb);
+
 /*! \brief Copy matrix from device to host
     @param[in]
     rows        [rocblas_int]
@@ -210,6 +211,14 @@ ROCBLAS_EXPORT rocblas_status rocblas_get_matrix(rocblas_int rows,
                                                  void*       b,
                                                  rocblas_int ldb);
 
+ROCBLAS_EXPORT rocblas_status rocblas_get_matrix_64(int64_t     rows,
+                                                    int64_t     cols,
+                                                    int64_t     elem_size,
+                                                    const void* a,
+                                                    int64_t     lda,
+                                                    void*       b,
+                                                    int64_t     ldb);
+
 /*! \brief Asynchronously copy vector from host to device
      \details
     rocblas_set_vector_async copies a vector from pinned host memory to device memory asynchronously.
@@ -241,6 +250,14 @@ ROCBLAS_EXPORT rocblas_status rocblas_set_vector_async(rocblas_int n,
                                                        rocblas_int incy,
                                                        hipStream_t stream);
 
+ROCBLAS_EXPORT rocblas_status rocblas_set_vector_async_64(int64_t     n,
+                                                          int64_t     elem_size,
+                                                          const void* x,
+                                                          int64_t     incx,
+                                                          void*       y,
+                                                          int64_t     incy,
+                                                          hipStream_t stream);
+
 /*! \brief Asynchronously copy vector from device to host
      \details
     rocblas_get_vector_async copies a vector from pinned host memory to device memory asynchronously.
@@ -272,6 +289,14 @@ ROCBLAS_EXPORT rocblas_status rocblas_get_vector_async(rocblas_int n,
                                                        rocblas_int incy,
                                                        hipStream_t stream);
 
+ROCBLAS_EXPORT rocblas_status rocblas_get_vector_async_64(int64_t     n,
+                                                          int64_t     elem_size,
+                                                          const void* x,
+                                                          int64_t     incx,
+                                                          void*       y,
+                                                          int64_t     incy,
+                                                          hipStream_t stream);
+
 /*! \brief Asynchronously copy matrix from host to device
      \details
     rocblas_set_matrix_async copies a matrix from pinned host memory to device memory asynchronously.
@@ -307,6 +332,15 @@ ROCBLAS_EXPORT rocblas_status rocblas_set_matrix_async(rocblas_int rows,
                                                        rocblas_int ldb,
                                                        hipStream_t stream);
 
+ROCBLAS_EXPORT rocblas_status rocblas_set_matrix_async_64(int64_t     rows,
+                                                          int64_t     cols,
+                                                          int64_t     elem_size,
+                                                          const void* a,
+                                                          int64_t     lda,
+                                                          void*       b,
+                                                          int64_t     ldb,
+                                                          hipStream_t stream);
+
 /*! \brief asynchronously copy matrix from device to host
      \details
     rocblas_get_matrix_async copies a matrix from device memory to pinned host memory asynchronously.
@@ -342,6 +376,15 @@ ROCBLAS_EXPORT rocblas_status rocblas_get_matrix_async(rocblas_int rows,
                                                        rocblas_int ldb,
                                                        hipStream_t stream);
 
+ROCBLAS_EXPORT rocblas_status rocblas_get_matrix_async_64(int64_t     rows,
+                                                          int64_t     cols,
+                                                          int64_t     elem_size,
+                                                          const void* a,
+                                                          int64_t     lda,
+                                                          void*       b,
+                                                          int64_t     ldb,
+                                                          hipStream_t stream);
+
 /*******************************************************************************
  * Function to set start/stop event handlers (for internal use only)
  ******************************************************************************/
